AtaProxyBlocking

Struct AtaProxyBlocking 

pub struct AtaProxyBlocking<'c>(/* private fields */);

Implementations

Source

impl<'c> AtaProxyBlocking<'c>

pub fn new(conn: &Connection) -> Result<AtaProxyBlocking<'c>>

Creates a new proxy with the default service & path.

pub fn builder(conn: &Connection) -> ProxyBuilder<'c, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'c>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'c>

The reference to the underlying zbus::Proxy.

pub fn pm_get_state(&self, options: HashMap<&str, Value<'_>>) -> Result<u8>

PmGetState method

pub fn pm_standby(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

PmStandby method

pub fn pm_wakeup(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

PmWakeup method

pub fn security_erase_unit( &self, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SecurityEraseUnit method

pub fn smart_get_attributes( &self, options: HashMap<&str, Value<'_>>, ) -> Result<Vec<(u8, String, u16, i32, i32, i32, i64, i32, HashMap<String, OwnedValue>)>>

SmartGetAttributes method

pub fn smart_selftest_abort( &self, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SmartSelftestAbort method

pub fn smart_selftest_start( &self, type_: &str, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SmartSelftestStart method

pub fn smart_set_enabled( &self, value: bool, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SmartSetEnabled method

pub fn smart_update(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

SmartUpdate method

pub fn aam_enabled(&self) -> Result<bool>

AamEnabled property

pub fn cached_aam_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the AamEnabled property, or None if the property is not cached.

pub fn receive_aam_enabled_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the AamEnabled property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn aam_supported(&self) -> Result<bool>

AamSupported property

pub fn cached_aam_supported( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the AamSupported property, or None if the property is not cached.

pub fn receive_aam_supported_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the AamSupported property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

AamVendorRecommendedValue property

Get the cached value of the AamVendorRecommendedValue property, or None if the property is not cached.

Create a stream for the AamVendorRecommendedValue property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn apm_enabled(&self) -> Result<bool>

ApmEnabled property

pub fn cached_apm_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the ApmEnabled property, or None if the property is not cached.

pub fn receive_apm_enabled_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the ApmEnabled property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn apm_supported(&self) -> Result<bool>

ApmSupported property

pub fn cached_apm_supported( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the ApmSupported property, or None if the property is not cached.

pub fn receive_apm_supported_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the ApmSupported property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn pm_enabled(&self) -> Result<bool>

PmEnabled property

pub fn cached_pm_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the PmEnabled property, or None if the property is not cached.

pub fn receive_pm_enabled_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the PmEnabled property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn pm_supported(&self) -> Result<bool>

PmSupported property

pub fn cached_pm_supported( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the PmSupported property, or None if the property is not cached.

pub fn receive_pm_supported_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the PmSupported property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn read_lookahead_enabled(&self) -> Result<bool>

ReadLookaheadEnabled property

pub fn cached_read_lookahead_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the ReadLookaheadEnabled property, or None if the property is not cached.

pub fn receive_read_lookahead_enabled_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the ReadLookaheadEnabled property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn read_lookahead_supported(&self) -> Result<bool>

ReadLookaheadSupported property

pub fn cached_read_lookahead_supported( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the ReadLookaheadSupported property, or None if the property is not cached.

pub fn receive_read_lookahead_supported_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the ReadLookaheadSupported property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn security_enhanced_erase_unit_minutes(&self) -> Result<i32>

SecurityEnhancedEraseUnitMinutes property

pub fn cached_security_enhanced_erase_unit_minutes( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>

Get the cached value of the SecurityEnhancedEraseUnitMinutes property, or None if the property is not cached.

pub fn receive_security_enhanced_erase_unit_minutes_changed( &self, ) -> PropertyIterator<'c, <Result<i32> as ResultAdapter>::Ok>

Create a stream for the SecurityEnhancedEraseUnitMinutes property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn security_erase_unit_minutes(&self) -> Result<i32>

SecurityEraseUnitMinutes property

pub fn cached_security_erase_unit_minutes( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>

Get the cached value of the SecurityEraseUnitMinutes property, or None if the property is not cached.

pub fn receive_security_erase_unit_minutes_changed( &self, ) -> PropertyIterator<'c, <Result<i32> as ResultAdapter>::Ok>

Create a stream for the SecurityEraseUnitMinutes property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn security_frozen(&self) -> Result<bool>

SecurityFrozen property

pub fn cached_security_frozen( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the SecurityFrozen property, or None if the property is not cached.

pub fn receive_security_frozen_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the SecurityFrozen property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_enabled(&self) -> Result<bool>

SmartEnabled property

pub fn cached_smart_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the SmartEnabled property, or None if the property is not cached.

pub fn receive_smart_enabled_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the SmartEnabled property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_failing(&self) -> Result<bool>

SmartFailing property

pub fn cached_smart_failing( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the SmartFailing property, or None if the property is not cached.

pub fn receive_smart_failing_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the SmartFailing property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_num_attributes_failed_in_the_past(&self) -> Result<i32>

SmartNumAttributesFailedInThePast property

pub fn cached_smart_num_attributes_failed_in_the_past( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>

Get the cached value of the SmartNumAttributesFailedInThePast property, or None if the property is not cached.

pub fn receive_smart_num_attributes_failed_in_the_past_changed( &self, ) -> PropertyIterator<'c, <Result<i32> as ResultAdapter>::Ok>

Create a stream for the SmartNumAttributesFailedInThePast property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_num_attributes_failing(&self) -> Result<i32>

SmartNumAttributesFailing property

pub fn cached_smart_num_attributes_failing( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>

Get the cached value of the SmartNumAttributesFailing property, or None if the property is not cached.

pub fn receive_smart_num_attributes_failing_changed( &self, ) -> PropertyIterator<'c, <Result<i32> as ResultAdapter>::Ok>

Create a stream for the SmartNumAttributesFailing property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_num_bad_sectors(&self) -> Result<i64>

SmartNumBadSectors property

pub fn cached_smart_num_bad_sectors( &self, ) -> Result<Option<<Result<i64> as ResultAdapter>::Ok>, <Result<i64> as ResultAdapter>::Err>

Get the cached value of the SmartNumBadSectors property, or None if the property is not cached.

pub fn receive_smart_num_bad_sectors_changed( &self, ) -> PropertyIterator<'c, <Result<i64> as ResultAdapter>::Ok>

Create a stream for the SmartNumBadSectors property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_power_on_seconds(&self) -> Result<u64>

SmartPowerOnSeconds property

pub fn cached_smart_power_on_seconds( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Get the cached value of the SmartPowerOnSeconds property, or None if the property is not cached.

pub fn receive_smart_power_on_seconds_changed( &self, ) -> PropertyIterator<'c, <Result<u64> as ResultAdapter>::Ok>

Create a stream for the SmartPowerOnSeconds property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_selftest_percent_remaining(&self) -> Result<i32>

SmartSelftestPercentRemaining property

pub fn cached_smart_selftest_percent_remaining( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>

Get the cached value of the SmartSelftestPercentRemaining property, or None if the property is not cached.

pub fn receive_smart_selftest_percent_remaining_changed( &self, ) -> PropertyIterator<'c, <Result<i32> as ResultAdapter>::Ok>

Create a stream for the SmartSelftestPercentRemaining property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_selftest_status(&self) -> Result<String>

SmartSelftestStatus property

pub fn cached_smart_selftest_status( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

Get the cached value of the SmartSelftestStatus property, or None if the property is not cached.

pub fn receive_smart_selftest_status_changed( &self, ) -> PropertyIterator<'c, <Result<String> as ResultAdapter>::Ok>

Create a stream for the SmartSelftestStatus property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_supported(&self) -> Result<bool>

SmartSupported property

pub fn cached_smart_supported( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the SmartSupported property, or None if the property is not cached.

pub fn receive_smart_supported_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the SmartSupported property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_temperature(&self) -> Result<f64>

SmartTemperature property

pub fn cached_smart_temperature( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>

Get the cached value of the SmartTemperature property, or None if the property is not cached.

pub fn receive_smart_temperature_changed( &self, ) -> PropertyIterator<'c, <Result<f64> as ResultAdapter>::Ok>

Create a stream for the SmartTemperature property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn smart_updated(&self) -> Result<u64>

SmartUpdated property

pub fn cached_smart_updated( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Get the cached value of the SmartUpdated property, or None if the property is not cached.

pub fn receive_smart_updated_changed( &self, ) -> PropertyIterator<'c, <Result<u64> as ResultAdapter>::Ok>

Create a stream for the SmartUpdated property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn write_cache_enabled(&self) -> Result<bool>

WriteCacheEnabled property

pub fn cached_write_cache_enabled( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the WriteCacheEnabled property, or None if the property is not cached.

pub fn receive_write_cache_enabled_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the WriteCacheEnabled property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn write_cache_supported(&self) -> Result<bool>

WriteCacheSupported property

pub fn cached_write_cache_supported( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the WriteCacheSupported property, or None if the property is not cached.

pub fn receive_write_cache_supported_changed( &self, ) -> PropertyIterator<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the WriteCacheSupported property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

Methods from Deref<Target = Proxy<'c>>

pub fn connection(&self) -> &Connection

Get a reference to the associated connection.

pub fn destination(&self) -> &BusName<'_>

Get a reference to the destination service name.

pub fn path(&self) -> &ObjectPath<'_>

Get a reference to the object path.

pub fn interface(&self) -> &InterfaceName<'_>

Get a reference to the interface.

pub fn introspect(&self) -> Result<String, Error>

Introspect the associated object, and return the XML description.

See the xml module for parsing the result.

pub fn cached_property<T>( &self, property_name: &str, ) -> Result<Option<T>, Error>

Get the cached value of the property property_name.

This returns None if the property is not in the cache. This could be because the cache was invalidated by an update, because caching was disabled for this property or proxy, or because the cache has not yet been populated. Use get_property to fetch the value from the peer.

pub fn cached_property_raw<'p>( &'p self, property_name: &'p str, ) -> Option<impl Deref<Target = Value<'static>> + 'p>

Get the cached value of the property property_name.

Same as cached_property, but gives you access to the raw value stored in the cache. This is useful if you want to avoid allocations and cloning.

pub fn get_property<T>(&self, property_name: &str) -> Result<T, Error>

Get the property property_name.

Get the property value from the cache or call the Get method of the org.freedesktop.DBus.Properties interface.

pub fn set_property<'t, T>( &self, property_name: &str, value: T, ) -> Result<(), Error>
where T: 't + Into<Value<'t>>,

Set the property property_name.

Effectively, call the Set method of the org.freedesktop.DBus.Properties interface.

pub fn call_method<'m, M, B>( &self, method_name: M, body: &B, ) -> Result<Arc<Message>, Error>

Call a method and return the reply.

Typically, you would want to use call method instead. Use this method if you need to deserialize the reply message manually (this way, you can avoid the memory allocation/copying, by deserializing the reply to an unowned type).

pub fn call<'m, M, B, R>(&self, method_name: M, body: &B) -> Result<R, Error>

Call a method and return the reply body.

Use call_method instead if you need to deserialize the reply manually/separately.

pub fn call_noreply<'m, M, B>( &self, method_name: M, body: &B, ) -> Result<(), Error>

Call a method without expecting a reply

This sets the NoReplyExpected flag on the calling message and does not wait for a reply.

pub fn receive_signal<'m, M>( &self, signal_name: M, ) -> Result<SignalIterator<'a>, Error>
where 'm: 'a, M: TryInto<MemberName<'m>>, <M as TryInto<MemberName<'m>>>::Error: Into<Error>,

Create a stream for signal named signal_name.

Errors

Apart from general I/O errors that can result from socket communications, calling this method will also result in an error if the destination service has not yet registered its well-known name with the bus (assuming you’re using the well-known name as destination).

pub fn receive_all_signals(&self) -> Result<SignalIterator<'a>, Error>

Create a stream for all signals emitted by this service.

Errors

Apart from general I/O errors that can result from socket communications, calling this method will also result in an error if the destination service has not yet registered its well-known name with the bus (assuming you’re using the well-known name as destination).

pub fn receive_property_changed<'name, T>( &self, name: &'name str, ) -> PropertyIterator<'a, T>
where 'name: 'a,

Get an iterator to receive owner changed events.

If the proxy destination is a unique name, the stream will be notified of the peer disconnection from the bus (with a None value).

If the proxy destination is a well-known name, the stream will be notified whenever the name owner is changed, either by a new peer being granted ownership (Some value) or when the name is released (with a None value).

Note that zbus doesn’t queue the updates. If the listener is slower than the receiver, it will only receive the last update.

pub fn receive_owner_changed(&self) -> Result<OwnerChangedIterator<'_>, Error>

Get an iterator to receive property changed events.

Note that zbus doesn’t queue the updates. If the listener is slower than the receiver, it will only receive the last update.

pub fn inner(&self) -> &Proxy<'a>

Get a reference to the underlying async Proxy.