LoopProxy

Struct LoopProxy 

pub struct LoopProxy<'c>(/* private fields */);

Implementations

Source

impl<'c> LoopProxy<'c>

pub async fn new(conn: &Connection) -> Result<LoopProxy<'c>>

Creates a new proxy with the default service & path.

pub fn builder(conn: &Connection) -> ProxyBuilder<'c, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'c>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'c>

The reference to the underlying zbus::Proxy.

pub async fn delete(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

Delete method

pub async fn set_autoclear( &self, value: bool, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SetAutoclear method

pub async fn autoclear(&self) -> Result<bool>

Autoclear property

pub fn cached_autoclear( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the Autoclear property, or None if the property is not cached.

pub async fn receive_autoclear_changed( &self, ) -> PropertyStream<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the Autoclear property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn backing_file(&self) -> Result<AsciiString>

BackingFile property

pub fn cached_backing_file( &self, ) -> Result<Option<<Result<AsciiString> as ResultAdapter>::Ok>, <Result<AsciiString> as ResultAdapter>::Err>

Get the cached value of the BackingFile property, or None if the property is not cached.

pub async fn receive_backing_file_changed( &self, ) -> PropertyStream<'c, <Result<AsciiString> as ResultAdapter>::Ok>

Create a stream for the BackingFile property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn setup_by_uid(&self) -> Result<u32>

SetupByUID property

pub fn cached_setup_by_uid( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

Get the cached value of the SetupByUid property, or None if the property is not cached.

pub async fn receive_setup_by_uid_changed( &self, ) -> PropertyStream<'c, <Result<u32> as ResultAdapter>::Ok>

Create a stream for the SetupByUid property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

Methods from Deref<Target = Proxy<'c>>

pub fn connection(&self) -> &Connection

Get a reference to the associated connection.

pub fn destination(&self) -> &BusName<'_>

Get a reference to the destination service name.

pub fn path(&self) -> &ObjectPath<'_>

Get a reference to the object path.

pub fn interface(&self) -> &InterfaceName<'_>

Get a reference to the interface.

pub async fn introspect(&self) -> Result<String, Error>

Introspect the associated object, and return the XML description.

See the xml module for parsing the result.

pub fn cached_property<T>( &self, property_name: &str, ) -> Result<Option<T>, Error>

Get the cached value of the property property_name.

This returns None if the property is not in the cache. This could be because the cache was invalidated by an update, because caching was disabled for this property or proxy, or because the cache has not yet been populated. Use get_property to fetch the value from the peer.

pub fn cached_property_raw<'p>( &'p self, property_name: &'p str, ) -> Option<impl Deref<Target = Value<'static>> + 'p>

Get the cached value of the property property_name.

Same as cached_property, but gives you access to the raw value stored in the cache. This is useful if you want to avoid allocations and cloning.

pub async fn get_property<T>(&self, property_name: &str) -> Result<T, Error>

Get the property property_name.

Get the property value from the cache (if caching is enabled) or call the Get method of the org.freedesktop.DBus.Properties interface.

pub async fn set_property<'t, T>( &self, property_name: &str, value: T, ) -> Result<(), Error>
where T: 't + Into<Value<'t>>,

Set the property property_name.

Effectively, call the Set method of the org.freedesktop.DBus.Properties interface.

pub async fn call_method<'m, M, B>( &self, method_name: M, body: &B, ) -> Result<Arc<Message>, Error>

Call a method and return the reply.

Typically, you would want to use call method instead. Use this method if you need to deserialize the reply message manually (this way, you can avoid the memory allocation/copying, by deserializing the reply to an unowned type).

pub async fn call<'m, M, B, R>( &self, method_name: M, body: &B, ) -> Result<R, Error>

Call a method and return the reply body.

Use call_method instead if you need to deserialize the reply manually/separately.

pub async fn call_noreply<'m, M, B>( &self, method_name: M, body: &B, ) -> Result<(), Error>

Call a method without expecting a reply

This sets the NoReplyExpected flag on the calling message and does not wait for a reply.

pub async fn receive_signal<'m, M>( &self, signal_name: M, ) -> Result<SignalStream<'a>, Error>
where 'm: 'a, M: TryInto<MemberName<'m>>, <M as TryInto<MemberName<'m>>>::Error: Into<Error>,

Create a stream for signal named signal_name.

pub async fn receive_all_signals(&self) -> Result<SignalStream<'a>, Error>

Create a stream for all signals emitted by this service.

pub async fn receive_property_changed<'name, T>( &self, name: &'name str, ) -> PropertyStream<'a, T>
where 'name: 'a,

Get a stream to receive property changed events.

Note that zbus doesn’t queue the updates. If the listener is slower than the receiver, it will only receive the last update.

If caching is not enabled on this proxy, the resulting stream will not return any events.

pub async fn receive_owner_changed( &self, ) -> Result<OwnerChangedStream<'_>, Error>

Get a stream to receive destination owner changed events.

If the proxy destination is a unique name, the stream will be notified of the peer disconnection from the bus (with a None value).

If the proxy destination is a well-known name, the stream will be notified whenever the name owner is changed, either by a new peer being granted ownership (Some value) or when the name is released (with a None value).

Note that zbus doesn’t queue the updates. If the listener is slower than the receiver, it will only receive the last update.