PartitionProxy

Struct PartitionProxy 

pub struct PartitionProxy<'c>(/* private fields */);

Implementations

Source

impl<'c> PartitionProxy<'c>

pub async fn new(conn: &Connection) -> Result<PartitionProxy<'c>>

Creates a new proxy with the default service & path.

pub fn builder(conn: &Connection) -> ProxyBuilder<'c, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'c>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'c>

The reference to the underlying zbus::Proxy.

pub async fn delete(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

Delete method

pub async fn resize( &self, size: u64, options: HashMap<&str, Value<'_>>, ) -> Result<()>

Resize method

pub async fn set_flags( &self, flags: u64, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SetFlags method

pub async fn set_name( &self, name: &str, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SetName method

pub async fn set_type( &self, type_: &str, options: HashMap<&str, Value<'_>>, ) -> Result<()>

SetType method

pub async fn flags(&self) -> Result<u64>

Flags property

pub fn cached_flags( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Get the cached value of the Flags property, or None if the property is not cached.

pub async fn receive_flags_changed( &self, ) -> PropertyStream<'c, <Result<u64> as ResultAdapter>::Ok>

Create a stream for the Flags property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn is_contained(&self) -> Result<bool>

IsContained property

pub fn cached_is_contained( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the IsContained property, or None if the property is not cached.

pub async fn receive_is_contained_changed( &self, ) -> PropertyStream<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the IsContained property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn is_container(&self) -> Result<bool>

IsContainer property

pub fn cached_is_container( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Get the cached value of the IsContainer property, or None if the property is not cached.

pub async fn receive_is_container_changed( &self, ) -> PropertyStream<'c, <Result<bool> as ResultAdapter>::Ok>

Create a stream for the IsContainer property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn name(&self) -> Result<String>

Name property

pub fn cached_name( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

Get the cached value of the Name property, or None if the property is not cached.

pub async fn receive_name_changed( &self, ) -> PropertyStream<'c, <Result<String> as ResultAdapter>::Ok>

Create a stream for the Name property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn number(&self) -> Result<u32>

Number property

pub fn cached_number( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

Get the cached value of the Number property, or None if the property is not cached.

pub async fn receive_number_changed( &self, ) -> PropertyStream<'c, <Result<u32> as ResultAdapter>::Ok>

Create a stream for the Number property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn offset(&self) -> Result<u64>

Offset property

pub fn cached_offset( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Get the cached value of the Offset property, or None if the property is not cached.

pub async fn receive_offset_changed( &self, ) -> PropertyStream<'c, <Result<u64> as ResultAdapter>::Ok>

Create a stream for the Offset property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn size(&self) -> Result<u64>

Size property

pub fn cached_size( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Get the cached value of the Size property, or None if the property is not cached.

pub async fn receive_size_changed( &self, ) -> PropertyStream<'c, <Result<u64> as ResultAdapter>::Ok>

Create a stream for the Size property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn table(&self) -> Result<OwnedObjectPath>

Table property

pub fn cached_table( &self, ) -> Result<Option<<Result<OwnedObjectPath> as ResultAdapter>::Ok>, <Result<OwnedObjectPath> as ResultAdapter>::Err>

Get the cached value of the Table property, or None if the property is not cached.

pub async fn receive_table_changed( &self, ) -> PropertyStream<'c, <Result<OwnedObjectPath> as ResultAdapter>::Ok>

Create a stream for the Table property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn type_(&self) -> Result<String>

Type property

pub fn cached_type_( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

Get the cached value of the Type property, or None if the property is not cached.

pub async fn receive_type__changed( &self, ) -> PropertyStream<'c, <Result<String> as ResultAdapter>::Ok>

Create a stream for the Type property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn uuid(&self) -> Result<String>

UUID property

pub fn cached_uuid( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

Get the cached value of the Uuid property, or None if the property is not cached.

pub async fn receive_uuid_changed( &self, ) -> PropertyStream<'c, <Result<String> as ResultAdapter>::Ok>

Create a stream for the Uuid property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

Methods from Deref<Target = Proxy<'c>>

pub fn connection(&self) -> &Connection

Get a reference to the associated connection.

pub fn destination(&self) -> &BusName<'_>

Get a reference to the destination service name.

pub fn path(&self) -> &ObjectPath<'_>

Get a reference to the object path.

pub fn interface(&self) -> &InterfaceName<'_>

Get a reference to the interface.

pub async fn introspect(&self) -> Result<String, Error>

Introspect the associated object, and return the XML description.

See the xml module for parsing the result.

pub fn cached_property<T>( &self, property_name: &str, ) -> Result<Option<T>, Error>

Get the cached value of the property property_name.

This returns None if the property is not in the cache. This could be because the cache was invalidated by an update, because caching was disabled for this property or proxy, or because the cache has not yet been populated. Use get_property to fetch the value from the peer.

pub fn cached_property_raw<'p>( &'p self, property_name: &'p str, ) -> Option<impl Deref<Target = Value<'static>> + 'p>

Get the cached value of the property property_name.

Same as cached_property, but gives you access to the raw value stored in the cache. This is useful if you want to avoid allocations and cloning.

pub async fn get_property<T>(&self, property_name: &str) -> Result<T, Error>

Get the property property_name.

Get the property value from the cache (if caching is enabled) or call the Get method of the org.freedesktop.DBus.Properties interface.

pub async fn set_property<'t, T>( &self, property_name: &str, value: T, ) -> Result<(), Error>
where T: 't + Into<Value<'t>>,

Set the property property_name.

Effectively, call the Set method of the org.freedesktop.DBus.Properties interface.

pub async fn call_method<'m, M, B>( &self, method_name: M, body: &B, ) -> Result<Arc<Message>, Error>

Call a method and return the reply.

Typically, you would want to use call method instead. Use this method if you need to deserialize the reply message manually (this way, you can avoid the memory allocation/copying, by deserializing the reply to an unowned type).

pub async fn call<'m, M, B, R>( &self, method_name: M, body: &B, ) -> Result<R, Error>

Call a method and return the reply body.

Use call_method instead if you need to deserialize the reply manually/separately.

pub async fn call_noreply<'m, M, B>( &self, method_name: M, body: &B, ) -> Result<(), Error>

Call a method without expecting a reply

This sets the NoReplyExpected flag on the calling message and does not wait for a reply.

pub async fn receive_signal<'m, M>( &self, signal_name: M, ) -> Result<SignalStream<'a>, Error>
where 'm: 'a, M: TryInto<MemberName<'m>>, <M as TryInto<MemberName<'m>>>::Error: Into<Error>,

Create a stream for signal named signal_name.

pub async fn receive_all_signals(&self) -> Result<SignalStream<'a>, Error>

Create a stream for all signals emitted by this service.

pub async fn receive_property_changed<'name, T>( &self, name: &'name str, ) -> PropertyStream<'a, T>
where 'name: 'a,

Get a stream to receive property changed events.

Note that zbus doesn’t queue the updates. If the listener is slower than the receiver, it will only receive the last update.

If caching is not enabled on this proxy, the resulting stream will not return any events.

pub async fn receive_owner_changed( &self, ) -> Result<OwnerChangedStream<'_>, Error>

Get a stream to receive destination owner changed events.

If the proxy destination is a unique name, the stream will be notified of the peer disconnection from the bus (with a None value).

If the proxy destination is a well-known name, the stream will be notified whenever the name owner is changed, either by a new peer being granted ownership (Some value) or when the name is released (with a None value).

Note that zbus doesn’t queue the updates. If the listener is slower than the receiver, it will only receive the last update.